<?php
/**
 * 2007-2020 PrestaShop SA and Contributors
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://www.prestashop.com for more information.
 *
 * @author    Mediacom87 <support@mediacom87.freshdesk.com>
 * @copyright 2008-today Mediacom87
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */
if (!defined('_PS_VERSION_')) {
    exit;
}
class MedBingPixelFreeClass
{
    public function __construct($module)
    {
        $this->module = $module;
    }

    public function isoCode($domain = false)
    {
        $iso = $this->module->context->language->iso_code;

        if ($iso == 'fr') {
            return 'fr';
        } elseif ($domain) {
            return 'com';
        } else {
            return 'en';
        }
    }

    public function medJsonModuleFile()
    {
        if (isset($this->module->module_key)
            && $this->module->module_key) {
            $conf = Configuration::getMultiple(['MED_JSON_TIME', 'MED_JSON_FILE']);

            if (!isset($conf['MED_JSON_TIME']) || $conf['MED_JSON_TIME'] < (time() - 604800)) {
                Configuration::updateValue('MED_JSON_TIME', time());
                $url_api = 'https://api-addons.prestashop.com/'
                    . _PS_VERSION_ . '/contributor/all_products/'
                    . $this->module->module_key . '/'
                    . $this->module->context->language->iso_code . '/'
                    . $this->module->context->country->iso_code;
                $conf['MED_JSON_FILE'] = Tools::file_get_contents($url_api);
                Configuration::updateValue('MED_JSON_FILE', $conf['MED_JSON_FILE']);
            }

            $modules = json_decode($conf['MED_JSON_FILE'], true);

            if (!is_array($modules) || isset($modules['errors'])) {
                Configuration::updateValue('MED_JSON_TIME', 0);

                return null;
            } else {
                return $modules;
            }
        } else {
            return null;
        }
    }

    public function medJsonFeedFile()
    {
        $conf = Configuration::getMultiple(['MED_FEED_TIME', 'MED_FEED_FILE']);

        if (!isset($conf['MED_FEED_TIME'])
            || $conf['MED_FEED_TIME'] < (time() - 604800)) {
            Configuration::updateValue('MED_FEED_TIME', time());
            $url_feed = 'https://www.mediacom87.fr/' . ($this->isoCode() == 'en' ? 'en/' : '') . 'feed.json';
            $conf['MED_FEED_FILE'] = Tools::file_get_contents($url_feed);
            Configuration::updateValue('MED_FEED_FILE', $conf['MED_FEED_FILE']);
        }

        $feed = json_decode($conf['MED_FEED_FILE'], true);

        if (!is_array($feed)) {
            Configuration::updateGlobalValue('MED_FEED_TIME', 0);

            return null;
        } else {
            return $feed;
        }
    }
}
