<?php
/**
 * 2007-2020 PrestaShop SA and Contributors
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://www.prestashop.com for more information.
 *
 * @author    Mediacom87 <support@mediacom87.freshdesk.com>
 * @copyright 2008-today Mediacom87
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */
if (!defined('_PS_VERSION_')) {
    exit;
}

include_once dirname(__FILE__) . '/class/mediacom87.php';

class MedBingPixelFree extends Module
{
    public $smarty;
    public $context;
    public $controller;
    public $conf;
    public $errors = [];
    public $mediacom87;
    public $tpl_path;
    public $addons_id = '';
    protected $config_form = false;

    public function __construct()
    {
        $this->name = 'medbingpixelfree';
        $this->tab = 'front_office_features';
        $this->version = '1.1.1';
        $this->author = 'Mediacom87';
        $this->need_instance = 0;
        $this->module_key = 'ae2710fa682bcc32d452ed5d84b1b86d';
        $this->ps_versions_compliancy = ['min' => '1.6.0.0', 'max' => '8.99.99'];

        $this->bootstrap = true;

        parent::__construct();

        $this->displayName = $this->l('Free module to add bing pixel tracking');
        $this->description = $this->l('Add the UET tag to my website');

        $this->conf = json_decode(Configuration::get($this->name), true);

        $this->mediacom87 = new MedBingPixelFreeClass($this);

        $this->tpl_path = _PS_ROOT_DIR_ . '/modules/' . $this->name;
    }

    public function install()
    {
        if (!parent::install()
            || !$this->defaultConf()
            || !$this->registerHook('displayHeader')) {
            return false;
        }

        return true;
    }

    public function uninstall()
    {
        if (!parent::uninstall()
            || !Configuration::deleteByName($this->name)) {
            return false;
        }

        return true;
    }

    public function getContent($tab = 'AdminModules')
    {
        $output = '';

        if (Tools::isSubmit('saveconf')) {
            $this->postProcess();

            if (!count($this->errors)) {
                $output .= $this->displayConfirmation($this->l('Settings updated'));
            }
        }

        $form_url = AdminController::$currentIndex
            . '&amp;configure=' . $this->name
            . '&amp;token='
            . Tools::getAdminToken($tab . (int) Tab::getIdFromClassName($tab) . (int) $this->context->cookie->id_employee);

        $this->context->smarty->assign([
            'form_url' => $form_url,
            'tpl_path' => _PS_ROOT_DIR_ . '/modules/' . $this->name,
            'img_path' => $this->_path . 'views/img/',
            'description' => $this->description,
            'author' => $this->author,
            'name' => $this->name,
            'version' => $this->version,
            'ps_version' => defined('_PS_VERSION_') ? _PS_VERSION_ : null,
            'tb_version' => defined('_TB_VERSION_') ? _TB_VERSION_ : null,
            'php_version' => phpversion(),
            'iso_code' => $this->mediacom87->isoCode(),
            'iso_domain' => $this->mediacom87->isoCode(true),
            'id_active_lang' => $this->context->language->id,
            'json_modules' => $this->mediacom87->medJsonModuleFile(),
            'mediacom87_feed' => $this->mediacom87->medJsonFeedFile(),
            'config' => $this->conf,
        ]);

        $this->context->controller->addJS($this->_path . 'libraries/js/riotcompiler.min.js');

        $this->context->controller->addCSS($this->_path . 'views/css/back.css');

        $output .= $this->display(__FILE__, 'views/templates/admin/admin.tpl');
        $output .= $this->display(__FILE__, 'libraries/prestui/ps-tags.tpl');

        return $output;
    }

    public function defaultConf()
    {
        $this->conf['uetag'] = 0;

        if (!Configuration::updateValue($this->name, json_encode($this->conf))) {
            return false;
        }

        return true;
    }

    private function postProcess()
    {
        $this->conf['uetag'] = (int) Tools::getValue('uetag');

        if (Configuration::updateValue($this->name, json_encode($this->conf))) {
            return true;
        } else {
            $this->errors[] = $this->l('Error during saving settings');

            return false;
        }
    }

    public function hookDisplayHeader()
    {
        if ($this->active
            && isset($this->conf['uetag'])
            && $this->conf['uetag']) {
            if (!$this->isCached('header.tpl', $this->getCacheId())) {
                $this->context->smarty->assign('uetag', $this->conf['uetag']);
            }

            return $this->display(__FILE__, 'header.tpl', $this->getCacheId());
        }
    }

    public function hookHeader()
    {
        return $this->hookDisplayHeader();
    }
}
